==> apo-ws-client-6.00.10.1-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerVDI.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="versionDiplome" type="{VersionDiplomeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}VersionDiplomeDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "versionDiplome"
})
@XmlRootElement(name = "creerVDI", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier_17102019")
public class CreerVDI {

    @XmlElement(required = true)
    protected VersionDiplomeDTO versionDiplome;

    /**
     * Obtient la valeur de la propriété versionDiplome.
     * 
     * @return
     *     possible object is
     *     {@link VersionDiplomeDTO }
     *     
     */
    public VersionDiplomeDTO getVersionDiplome() {
        return versionDiplome;
    }

    /**
     * Définit la valeur de la propriété versionDiplome.
     * 
     * @param value
     *     allowed object is
     *     {@link VersionDiplomeDTO }
     *     
     */
    public void setVersionDiplome(VersionDiplomeDTO value) {
        this.versionDiplome = value;
    }

}

==> apo-ws-client-6.00.51.1-sources.jar: fr/univlorraine/apowsclient/creationSE/CreerVDI.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="versionDiplome" type="{VersionDiplomeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}VersionDiplomeDTO" form="unqualified"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "versionDiplome"
})
@XmlRootElement(name = "creerVDI", namespace = "gouv.education.apogee.commun.servicesmetiers.CreationSEMetier")
public class CreerVDI {

    @XmlElement(required = true)
    protected VersionDiplomeDTO versionDiplome;

    /**
     * Obtient la valeur de la propriété versionDiplome.
     * 
     * @return
     *     possible object is
     *     {@link VersionDiplomeDTO }
     *     
     */
    public VersionDiplomeDTO getVersionDiplome() {
        return versionDiplome;
    }

    /**
     * Définit la valeur de la propriété versionDiplome.
     * 
     * @param value
     *     allowed object is
     *     {@link VersionDiplomeDTO }
     *     
     */
    public void setVersionDiplome(VersionDiplomeDTO value) {
        this.versionDiplome = value;
    }

}
